============
 nti.mailer
============

.. image:: https://travis-ci.org/NextThought/nti.mailer.svg?branch=master
    :target: https://travis-ci.org/NextThought/nti.mailer

.. image:: https://coveralls.io/repos/github/NextThought/nti.mailer/badge.svg?branch=master
    :target: https://coveralls.io/github/NextThought/nti.mailer?branch=master

.. image:: https://readthedocs.org/projects/ntimailer/badge/?version=latest
   :target: https://ntimailer.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
